class Table():
    def __init__(self, players_list, big_blind, small_blind, button):
        self.players_list = players_list
        self.big_blind = big_blind
        self.small_blind = small_blind
        self.button = button
 

    def add_players(self, player):
        self.players_list.append(player)
        
    def move_button(self):
        self.button += 1
        
    def retrieve_button(self):
        pass



import deck
import pokertable
import players
import dealer_holdem
import rules_holdem
import time

cody = players.Player('cody4321', 1500)
darren = players.Player('d_money', 1500)
table_players = [cody, darren]
newtable = pokertable.Table(table_players, 20, 10, 0)

players_list = newtable.players_list
button = 0
big_blind = 20
small_blind = 10

suits_dict = {1: 'c', 2: 'd', 3: 'h', 4: 's'}

ranks_dict = {1: '2', 2: '2', 3: '3', 4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9', 10: '10', 11: 'J', 12: 'Q', 13: 'K', 14: 'A'}

ranks_spaces = {1: 1, 2: 1, 3: 1, 4: 1, 5: 1, 6: 1, 7: 1, 8: 1, 9: 1, 10: 0, 11: 1, 12: 1, 13: 1, 14: 1}

newdeck = deck.Deck()
newdeck.shuffle()


def starter():
    newdeck = deck.Deck()
    newdeck.shuffle()



print ('"newdeck" has been generated and shuffled \n')


class Test():
    @staticmethod
    def determine_total_chipcount(players):
        total_chipcount = 0
        for player in players:
            total_chipcount += player.chips
        return total_chipcount


    @staticmethod
    #check that chips are the same as the game started, not higher or lower
    def ensure_chipcount(players, total_chipcount):
        actual_chipcount = 0
        for player in players:
            actual_chipcount += player.chips
        if not actual_chipcount == total_chipcount:
            print 'We are missing chips?!?!'
            raise AssertionError
        print '\nIn tests.py...Chipcount is clear\n'
        time.sleep(6)






    @staticmethod
    def viewdeck(deck):
        for index, card in enumerate(deck.cards_list):
        
            if len(str(index)) == 2:
                indexspaces = ''
            else:
                indexspaces = ' '
            s = ' '
            spaces = s * ranks_spaces[card.Rank]
            
            print ('Index %d: ' % index, '%s' % indexspaces, '%s%s' % (ranks_dict[card.Rank], spaces), suits_dict[card.Suit], '\n')
    
    
    @staticmethod
    def viewhand(hand):
        for index, card in enumerate(hand):
            print ('%s%s' % (card.Rank, suits_dict[card.Suit]))
            
            
    @staticmethod
    def deal_straight_flush(deck):
        myhand = []
        for index, card in enumerate(deck.cards_list):
            if card.Rank == 7 and card.Suit == 4:
                 myhand.append(deck.pick(index))
            if card.Rank == 9 and card.Suit == 4:
                 myhand.append(deck.pick(index))
            if card.Rank == 10 and card.Suit == 4:
                 myhand.append(deck.pick(index))
            if card.Rank == 11 and card.Suit == 4:
                 myhand.append(deck.pick(index))
            if card.Rank == 8 and card.Suit == 4:
                 myhand.append(deck.pick(index))
        print (myhand)
        return myhand
        
        
    @staticmethod
    def deal_boat(deck):
        myhand = []
        trips = 0
        index1 = 0
        while trips < 3:
            if deck.cards_list[index1].Rank == 7:
                myhand.append(deck.pick(index1))
                trips += 1
            index1 += 1

        pair = 0
        index2 = 0
        while pair < 2:
            if deck.cards_list[index2].Rank == 5:
                myhand.append(deck.pick(index2))
                pair += 1
            index2 += 1
        return myhand

    @staticmethod
    def deal_trips(deck):
        myhand = []
        trips = 0
        index1 = 0
        while trips < 3:
            if deck.cards_list[index1].Rank == 7:
                myhand.append(deck.pick(index1))
                trips += 1
            index1 += 1
        while count < 4:
            index = 49
            myhand.append(deck.pick(index))
            index -= 1
            count += 1
        return myhand
          
          
    @staticmethod
    def deal_twopair(deck):
        myhand = []
        pair1 = 0
        index1 = 0
        while pair1 < 2:
            if deck.cards_list[index1].Rank == 7:
                myhand.append(deck.pick(index1))
                pair1 += 1
            index1 += 1
        pair2 = 0
        index2 = 0
        while pair2 < 2:
            if deck.cards_list[index2].Rank == 5:
                myhand.append(deck.pick(index2))
                pair2 += 1
            index2 += 1
        index3 = 0
        while len(myhand) < 5:
            if deck.cards_list[index3].Rank == 9:
                myhand.append(deck.pick(index3))
            index3 += 1
        print (myhand)
        return myhand
            
    @staticmethod
    def deal_pair(deck):
        myhand = []
        pair1 = 0
        index1 = 0
        while pair1 < 2:
            if deck.cards_list[index1].Rank == 7:
                myhand.append(deck.pick(index1))
                pair1 += 1
            index1 += 1
        index2 = 0
        kicker1 = None
        while not kicker1:
            if deck.cards_list[index2].Rank == 9:
                myhand.append(deck.pick(index2))
                kicker1 = 1
            index2 += 1
        index3 = 0
        kicker2 = None
        while not kicker2:
            if deck.cards_list[index3].Rank == 4:
                myhand.append(deck.pick(index3))
                kicker2 = 1
            index3 += 1
        index4 = 0
        kicker3 = None
        while not kicker3:
            if deck.cards_list[index4].Rank == 12:
                myhand.append(deck.pick(index4))
                kicker3 = 1
            index4 += 1
        return myhand
        

    @staticmethod
    def test_awards(players, chips):
        for player in players:
            player.award(chips)
     

       
#view = Test().viewdeck(newdeck)

# straightflush_check works!!!
#myhandstr8flush = Test().deal_straight_flush(newdeck)
#print ('myhandstr8flush:')
#viewmyhand = Test().viewhand(myhandstr8flush)

#myhand2pair = Test().deal_twopair(newdeck)
#print ('myhand2pair:')
#viewmyhand = Test().viewhand(myhand2pair)

#myhandboat = Test().deal_boat(newdeck)
#print ('myhandboat:')
#viewmyhand = Test().viewhand(myhandboat)

#myhandpair = Test().deal_pair(newdeck)
#print ('myhandpair:')
#viewmyhand = Test().viewhand(myhandpair)

#Test().test_awards(players_list, 20)

#print (cody.chips)

#print (darren.chips)
# to view the deck:
# tests.Test().viewdeck(tests.newdeck)



class Organize_Pots():
    @staticmethod
    def organize_pots(bet, current_player, table_pots, players_at_table):

        pots = table_pots

        pot_counter = 0
        #print '\nBeginning "organize_pot"...'
        #print '\nthe bet: %d' % bet
        #print '\nthe current player: %s' % current_player.screen_name
        #for pot in pots:
        #    print 'Pot %d:' % (pot_counter + 1)
        #    print 'Pot size: %d' % pots[pot_counter]['pot']
         #   print 'Bet to match for this pot: %d' % pots[pot_counter]['match']
         #   print 'Any all in? %s' % pots[pot_counter]['any_all_in']
         #   pot_counter += 1

        bets_to_match = []
        for pot in pots:
            bets_to_match.append(pot['match'])

        highest_pot = len(pots) - 1

        different_bet = True


        bet_increase = bet - current_player.current_bet
        print 'Bet increase: %d' % bet_increase

        new_current_investment = bet_increase + current_player.current_investment 
        print 'New current investment: %d' % new_current_investment

        current_player.current_investment += bet_increase
        print 'current player\'s investment: %d' % current_player.current_investment

        current_player.current_bet = bet
        print 'Current player\'s new current bet: %d' % current_player.current_bet

        current_player.chips -= bet_increase
        print 'player chips before testing for all in: %d' % current_player.chips
        if current_player.chips == 0:
            current_player.all_in = True

        for index, pot in enumerate(pots):
            if new_current_investment == pots[index]['match']:
                different_bet = False

        #determine if we need to insert a new pot
        if different_bet == True:
            if new_current_investment > pots[highest_pot]['match']:
                if pots[highest_pot]['any_all_in'] == False:
                    pots[highest_pot]['match'] = new_current_investment
                    if current_player.all_in == True:
                        pots[highest_pot]['any_all_in'] = True                        
                elif pots[highest_pot]['any_all_in'] == True:
                    pots.append({'pot': 0, 'match': new_current_investment, 'any_all_in': False})
                    if current_player.all_in == True:
                        #the new highest pot is this one
                        pots[highest_pot + 1]['any_all_in'] = True
            elif new_current_investment < pots[highest_pot]['match']:
                for index, pot in enumerate(pots):
                    print 'index: %d, pot: %s' % (index, pot)
                    if new_current_investment < pots[index]['match']:
                        pots.insert((index), {'pot': 0, 'match': new_current_investment, 'any_all_in': True})
                        break

        #reorganize/correct the chip total for pots
        for index, pot in enumerate(pots): 
            pots[index]['pot'] = 0
            pot_total = 0
            for player in players_at_table:
                if index == 0:
                    if player.current_investment >= pots[index]['match']:
                        pot_total += pots[index]['match']
                    elif player.current_investment < pots[index]['match']:
                        pot_total += player.current_investment
                elif index > 0:
                    if player.current_investment <= pots[index - 1]['match']:
                        continue
                    elif player.current_investment > pots[index - 1]['match']:
                        if player.current_investment >= pots[index]['match']:
                            pot_total += pots[index]['match'] - pots[index -1]['match']
                        elif player.current_investment < pots[index]['match']:
                            pot_total += player.current_investment - pots[index -1]['match']
            pots[index]['pot'] = pot_total
            

        print 'Ending "organize_pot"...'
        pot_counter = 0
        for pot in pots:
            print 'Pot %d:' % (pot_counter + 1)
            print 'Pot size: %d' % pots[pot_counter]['pot']
            print 'Bet to match for this pot: %d' % pots[pot_counter]['match']
            print 'Any all in? %s' % pots[pot_counter]['any_all_in']
            pot_counter += 1
        return (pots)




import deck

class Dealer():

    suits_dict = {1: 'c', 2: 'd', 3: 'h', 4: 's'}
    ranks_dict = {1: '2', 2: '2', 3: '3', 4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9', 10: '10', 11: 'J', 12: 'Q', 13: 'K', 14: 'A'}

    
    @staticmethod
    def deal_player_hand(players, deck):
        deck.shuffle()
        print 'dealing hands'
        dealt = 0
        while dealt < 2:
            for player in players:
                player.cards.append(deck.draw())
            dealt += 1

    @staticmethod
    def deal_omaha_hand(players, deck):
        deck.shuffle()
        print 'dealing hands'
        dealt = 0
        while dealt < 4:
            for player in players:
                player.cards.append(deck.draw())
            dealt += 1
        for player in players:
            print player.cards


    @staticmethod
    def deal_flop(deck):
        board = []
        flopcards = 0
        while flopcards < 3:
            board.append(deck.draw())
            flopcards += 1
        return board
        
    @staticmethod
    def deal_turn(deck, board):
        board.append(deck.draw())
        return board

    @staticmethod
    def deal_river(deck, board):
        board.append(deck.draw())
        return board


    @staticmethod
    def combine_hand_with_board(board, players):
        pass



#4 = spades
#3 = hearts
#2 = diamonds
#1 = clubs

import random, time


class Suit():
 Clubs, Diamonds, Hearts, Spades = range(1,5)
 
 
class Card():
 Suit = None
 Rank = None
 
 def __init__(self, suit, rank):
  self.Suit = suit
  self.Rank = rank

# deck adds 52 cards per instance to the actual deck class-
# newdeck = Deck() 52
# newdeck2 = Deck() 104 and so on

#nvm bug fixed by removing cards_list from class level and hiding it in init

class Deck():
    def __init__(self):
        self.cards_list = []
        for i in range(2,15):
            new_card = Card(Suit.Spades, i)
            self.cards_list.append(new_card)
            new_card = Card(Suit.Hearts, i)
            self.cards_list.append(new_card)
            new_card = Card(Suit.Diamonds, i)
            self.cards_list.append(new_card)
            new_card = Card(Suit.Clubs, i)
            self.cards_list.append(new_card)

        self.deck_length = len(self.cards_list)

    #debug only
    def debugdeck(self):
        for index, card in enumerate(self.cards_list):
            print (self.cards_list[index].Suit)
            print (self.cards_list[index].Rank)
        
    def _swap(self, i, j):
        temp = self.cards_list[i]
        self.cards_list[i] = self.cards_list[j]
        self.cards_list[j] = temp


    def shuffle(self):
        print 'shufflin!'
        start_time = time.clock()
        shuffles = 0
        while shuffles < 50:
            for i in range(0, 52):
                j = self.get_random()
                self._swap(i, j)
            shuffles +=1
        end_time = (time.clock() - start_time)
        print "%f seconds" % end_time


    def get_random(self):
        return int((random.SystemRandom(random.seed()).random())*51)

    #draws a card off the 'top' of the deck (the end of the list of cards)
    def draw(self):
        return self.cards_list.pop()

    #draw a certain card
    def select(self, a):
        return self.cards_list.pop(a)
        
    #this method picks a card, but doesn't actually remove it from the deck
    def pick(self, a):
        return self.cards_list[a]
        
  

  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  



import deck

class Card_Dict():
    suits_dict = {1: 'c', 2: 'd', 3: 'h', 4: 's'}
    ranks_dict = {1: '2', 2: '2', 3: '3', 4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9', 10: '10', 11: 'J', 12: 'Q', 13: 'K', 14: 'A'}

class Hand_Ranks():
    High_card, Pair, Two_pair, Trips, Straight, Flush, Boat, Quads, Straight_flush = range(1, 10)
    hand_ranks_dict = {1: 'high card', 2: 'pair', 3: 'two pair', 4: 'trips', 5: 'straight', 6: 'flush', 7: 'boat', 8: 'quads', 9: 'straight flush'}


class Holdem_rules():
    @staticmethod
    def check_consecutive(a, b):
        if a == (b - 1):
            return True
        else:
            return False
    #breaking off the inner for loop into a function. will return false if not consecutive. will need to use list splicing to tear off the last 5 items, middle 5 items, or first 5 items...
    #h = (hand_length - 5) cuz we count backwards from h to 0
    @staticmethod
    def straight_check(hand):
        this_hand = []
        for index, card in enumerate(hand):
            this_hand.append(hand[index].Rank)
        this_hand.sort()
        is_straight = False
        hand_length = len(hand)
        consecutive = 0
        h = (hand_length - 5)
        i = 0
        for j in range(h, -1, -1):
            consecutive = 0
            for i in range(0, 4):
                if Holdem_rules().check_consecutive(this_hand[i + j], this_hand[i + j + 1]) == True:
                    consecutive += 1
            if consecutive == 4:
                return (this_hand[j + 4])
                # since straights are always consecutive, no need for kickers
        return False

    #h = (hand_length - 5 + 1) cuz h ends the range)
    @staticmethod
    def flush_check(hand):
        suit_list = []
        for card in hand:
            suit_list.append(card.Suit)
        hand_length = len(hand)
        h = (hand_length - 5 + 1)
        for j in range(0, h):
            suitcount = suit_list.count(suit_list[j])
            if suitcount >= 5:
                flushlist = []
                for index, card in enumerate(hand):
                    if card.Suit == suit_list[j]:
                        flushlist.append(hand[index].Rank)
                flushcount = len(flushlist)
                flushlist.sort()
                flush_high_card = flushlist[flushcount - 1]
                flush_kickers = flushlist[0:(flushcount - 1)]
                suit = suit_list[j]
                return (flush_high_card, flush_kickers, {'suit': suit})
        return False

    #h = (hand_length - 5 + 2) because quads only needs to check 4 at a time, up to the 4th spot
    @staticmethod
    def quads_check(hand):
        hand_length = len(hand)
        h = (hand_length - 5 + 2)
        for i in range(0, h):
            if hand.count(hand[i].Rank) == 4:
                quads = hand[i].Rank
                kickers = []
                for card in hand:
                    if card.Rank != quads:
                        kickers.append(card.Rank)
                kickers.sort
                kicker = []
                kicker.append(kickers[hand_length - 5])
                return (hand[i], kicker)
        return False

    @staticmethod
    def straightflush_check(hand):
        if Holdem_rules().straight_check(hand):
            if Holdem_rules().flush_check(hand):
                flushlist = []
                flushsuit = Holdem_rules().flush_check(hand)[2]['suit']
                for index, card in enumerate(hand):
                    if card.Suit == flushsuit:
                        flushlist.append(hand[index])
                checked_straightflush = Holdem_rules().straight_check(flushlist)
                if checked_straightflush:
                    return (checked_straightflush, {'suit': flushsuit})
                else:
                    return False
                #flushcount = len(suit_list)
                #flushcount.sort()
                

    @staticmethod
    def royalflush_check(hand):
        results = Holdem_rules().straightflush_check(hand)
        if results[0] == 14:
            return (results[1])
        else:
            False
            
    @staticmethod
    def boat_check(hand):
        hand_length = len(hand)
        h = (hand_length - 5 + 3)
        this_hand = []
        for index, card in enumerate(hand):
            this_hand.append(hand[index].Rank)
        for i in range(0, h):
            if this_hand.count(this_hand[i]) == 3:
                trips = this_hand[i]
                for i in range(0, h+1):
                    if this_hand[i] != trips:
                        if this_hand.count(this_hand[i]) == 2:
                            pair = this_hand[i]
                            return (trips, pair)                
        return False
        
    @staticmethod
    def trips_check(hand):
        hand_length = len(hand)
        h = (hand_length - 5 + 3)
        this_hand = []
        for index, card in enumerate(hand):
            this_hand.append(hand[index].Rank)
        for i in range(0, h):
            if this_hand.count(this_hand[i]) == 3:
                kickers = []
                kicker_starter = []
                for card in this_hand:
                    kicker_starter.append(card)
                count = 0
                while count > 4:
                    try:
                        kicker_starter.remove(this_hand[i])
                        count += 1
                    except ValueError:
                        break
                kicker_starter.sort()
                length = len(kicker_starter)
                kickers.append(kicker_starter[length - 1])
                kickers.append(kicker_starter[length - 2])
                kickers.sort()
                return (this_hand[i], kickers)
        
    @staticmethod
    def twopair_check(hand):
        hand_length = len(hand)
        h = (hand_length - 5 + 4)
        this_hand = []
        for index, card in enumerate(hand):
            this_hand.append(hand[index].Rank)
        for i in range(0, h):
            if this_hand.count(this_hand[i]) == 2:
                pair1 = this_hand[i]
                for i in range(0, h):
                    if this_hand[i] != pair1:
                        if this_hand.count(this_hand[i]) == 2:
                            pair2 = this_hand[i]
                            if pair1 > pair2:
                                highest_pair = pair1
                                lowest_pair = pair2
                            else:
                                highest_pair = pair2
                                lowest_pair = pair1
                            kicker = []
                            for card in this_hand:
                                if card != pair1 and card != pair2:
                                    kicker.append(card)
                            kicker.sort()
                            length = len(kicker)
                            kicker.append(length - 1)
                            return (highest_pair, lowest_pair, kicker)                
        return False
        
        
    @staticmethod
    #need 3 kickers
    def pair_check(hand):
        hand_length = len(hand)
        h = (hand_length - 5 + 4)
        this_hand = []
        for index, card in enumerate(hand):
            this_hand.append(hand[index].Rank)
        for i in range(0, h):
            if this_hand.count(this_hand[i]) == 2:
                pair = this_hand[i]
                kickers_start = []
                for index, rank in enumerate(this_hand):
                    if rank != pair:
                        kickers_start.append(this_hand[index])
                kickers_start.sort()
                kickers = []
                kickers.append(kickers_start[hand_length - 3])
                kickers.append(kickers_start[hand_length - 4])
                kickers.append(kickers_start[hand_length - 5])
                kickers.sort()
                #print 'pair: %d, kickers: %s' % (pair, kickers)
                return (pair, kickers)
                
    @staticmethod
    def highcard_check(hand):
        hand_length = len(hand)
        high_card = (hand_length - 1)
        this_hand = []
        for index, card in enumerate(hand):
            this_hand.append(hand[index].Rank)
        this_hand.sort()
        start = (hand_length - 5)
        end = (hand_length - 1)
        kickers = this_hand[start:end]
        return (high_card, kickers)
        
                
    @staticmethod
    def evaluate_hand(player):

        hand = player.cards

        flush = Holdem_rules().flush_check(hand)
        if flush:
            straightflush = Holdem_rules().straightflush_check(hand)
            if straightflush:
                print "\n%s has a straight flush!" % player.screen_name
                return (9, straightflush[0], straightflush[1])

        quads = Holdem_rules().quads_check(hand)
        if quads:
            print "\n%s has quads!" % player.screen_name
            return (8, quads[0], quads[1])

        boat = Holdem_rules().boat_check(hand)
        if boat:
            print "\n%s has a boat!" % player.screen_name
            return (7, boat[0], boat[1])

        flush = Holdem_rules().flush_check(hand)
        if flush:
            print "\n%s has a flush!" % player.screen_name
            return (6, flush[0], flush[1], flush[2])

        straight = Holdem_rules().straight_check(hand)
        if straight:
            print "\n%s has a straight!" % player.screen_name
            return (5, straight)

        trips = Holdem_rules().trips_check(hand)
        if trips:
            print "\n%s has trips!" % player.screen_name
            return (4, trips[0], trips[1])

        twopair = Holdem_rules().twopair_check(hand)
        if twopair:
            print "\n%s has two pair!" % player.screen_name
            return (3, twopair[0], twopair[1], twopair[2])

        pair = Holdem_rules().pair_check(hand)
        if pair:
            print "\n%s has a pair!" % player.screen_name
            return (2, pair[0], pair[1])

        highcard = Holdem_rules().highcard_check(hand)
        print "\n%s has a highcard!" % player.screen_name
        return (1, highcard[0], highcard[1])            

    @staticmethod
    def make_hand_dict(player):
        return {'screen_name': player.screen_name, 'hand': player.cards}

    @staticmethod
    def make_hands_list(players):
        hands_list = []
        for player in players:
            hand_dict = Holdem_rules().make_hand_dict(player)
            hands_list.append(hand_dict)
        return hands_list


    #compare hands between multiple playesr
    @staticmethod
    def compare_hands(players):
        for player in players:
            player.hand_rank = Holdem_rules().evaluate_hand(player)
        hand_ranks = []
        for player in players:
            hand_ranks.append(player.hand_rank[0])
        hand_ranks.sort()
        handcount = len(hand_ranks)
        end = (handcount - 1)
        high_hand = hand_ranks[end]
        print '\nhigh hand: %s\n' % Hand_Ranks().hand_ranks_dict[high_hand]
        contenders = []
        winners = []
        for player in players:
            if player.hand_rank[0] == high_hand:
                contenders.append(player)
        if len(contenders) == 1:
            winners.append(contenders[0])
            return winners
        else:
        #else, if there are more than 1 person with same type of hand but we dont know who won
            #check high card
            if high_hand == 1:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                if contenders_2 == 1:
                    winners.append(contenders_2[0])
                    return winners
                else:
                #if the highcard ties evaluate highest kicker
                    end_of_list = len(contenders_2) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in contenders_2:
                        remaining_ranks.append(player.hand_rank[2][3])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_3 = []
                    for player in contenders_2:
                        if player.hand_rank[2][3] == leading_rank:
                            contenders_3.append(player)
                    if contenders_3 == 1:
                        winners.append(contenders_3[0])
                        return winners
                    else:
                    #if the highest kicker ties evaluate second highest kicker
                        end_of_list = len(contenders_3) - 1
                        remaining_ranks = []
                        leading_rank = None
                        for player in contenders_3:
                            remaining_ranks.append(player.hand_rank[2][2])
                        remaining_ranks.sort()
                        leading_rank = remaining_ranks[end_of_list]
                        contenders_4 = []
                        for player in contenders_3:
                            if player.hand_rank[2][2] == leading_rank:
                                contenders_4.append(player)
                        if contenders_4 == 1:
                            winners.append(contenders_4[0])
                            return winners
                        else:
                        #if the second highest kicker ties evaluate third highest kicker
                            end_of_list = len(contenders_4) - 1
                            remaining_ranks = []
                            leading_rank = None
                            for player in contenders_4:
                                remaining_ranks.append(player.hand_rank[2][1])
                            remaining_ranks.sort()
                            leading_rank = remaining_ranks[end_of_list]
                            contenders_5 = []
                            for player in contenders_5:
                                if player.hand_rank[2][1] == leading_rank:
                                    contenders_5.append(player)
                            if contenders_5 == 1:
                                winners.append(contenders_5[0])
                                return winners
                            else:
                            #if the third highest kicker ties evaluate lowest kicker
                                end_of_list = len(contenders_5) - 1
                                remaining_ranks = []
                                leading_rank = None
                                for player in contenders_5:
                                    remaining_ranks.append(player.hand_rank[2][0])
                                remaining_ranks.sort()
                                leading_rank = remaining_ranks[end_of_list]
                                contenders_6 = []
                                for player in contenders_6:
                                    if player.hand_rank[2][0] == leading_rank:
                                        contenders_6.append(player)
                                winners = contenders_6
                                return winners


            #check a pair
            elif high_hand == 2:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                if len(contenders_2) == 1:
                    winners = contenders_2
                    return winners
                else:
                #if the pair ties evaluate highest kicker
                    end_of_list = len(contenders_2) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in contenders_2:
                        remaining_ranks.append(player.hand_rank[2][2])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_3 = []
                    for player in contenders_2:
                        if player.hand_rank[2][2] == leading_rank:
                            contenders_3.append(player)
                    if contenders_3 == 1:
                        winners.append(contenders_3[0])
                        return winners
                    else:
                    #if the highest kicker ties evaluate middle kicker
                        end_of_list = len(contenders_3) - 1
                        remaining_ranks = []
                        leading_rank = None
                        for player in contenders_3:
                            remaining_ranks.append(player.hand_rank[2][1])
                        remaining_ranks.sort()
                        leading_rank = remaining_ranks[end_of_list]
                        contenders_4 = []
                        for player in contenders_3:
                            if player.hand_rank[2][1] == leading_rank:
                                contenders_4.append(player)
                        if contenders_4 == 1:
                            winners.append(contenders_4[0])
                            return winners
                        else:
                        #if the second highest kicker ties evaluate lowest kicker
                            end_of_list = len(contenders_4) - 1
                            remaining_ranks = []
                            leading_rank = None
                            for player in contenders_4:
                                remaining_ranks.append(player.hand_rank[2][0])
                            remaining_ranks.sort()
                            leading_rank = remaining_ranks[end_of_list]
                            contenders_5 = []
                            for player in contenders_5:
                                if player.hand_rank[2][0] == leading_rank:
                                    contenders_5.append(player)
                            winners = contenders_5
                            return winners

            
            #check 2 pair
            elif high_hand == 3:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                if contenders_2 == 1:
                    winners.append(contenders_2[0])
                    return winners
                else:
                #if the higher pair ties evaluate lower pair
                    end_of_list = len(contenders_2) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in contenders_2:
                        remaining_ranks.append(player.hand_rank[2])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_3 = []
                    for player in contenders_2:
                        if player.hand_rank[2] == leading_rank:
                            contenders_3.append(player)
                    if contenders_3 == 1:
                        winners.append(contenders_3[0])
                        return winners
                    else:
                    #if both pairs tie evaluate the kicker
                        end_of_list = len(contenders_3) - 1
                        remaining_ranks = []
                        leading_rank = None
                        for player in contenders_3:
                            remaining_ranks.append(player.hand_rank[3])
                        remaining_ranks.sort()
                        leading_rank = remaining_ranks[end_of_list]
                        contenders_4 = []
                        for player in contenders_3:
                            if player.hand_rank[3] == leading_rank:
                                contenders_4.append(player)
                        winners = contenders_4
                        return winners
                

            #check trips
            elif high_hand == 4:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                if contenders_2 == 1:
                    winners.append(contenders_2[0])
                    return winners
                else:
                #if the trips ties evaluate higher kicker
                    end_of_list = len(contenders_2) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in contenders_2:
                        remaining_ranks.append(player.hand_rank[2][1])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_3 = []
                    for player in contenders_2:
                        if player.hand_rank[2][1] == leading_rank:
                            contenders_3.append(player)
                    if contenders_3 == 1:
                        winners.append(contenders_3[0])
                        return winners
                    else:
                    #if the higher kicker ties evaluate lower kicker
                        end_of_list = len(contenders_3) - 1
                        remaining_ranks = []
                        leading_rank = None
                        for player in contenders_3:
                            remaining_ranks.append(player.hand_rank[2][0])
                        remaining_ranks.sort()
                        leading_rank = remaining_ranks[end_of_list]
                        contenders_4 = []
                        for player in contenders_3:
                            if player.hand_rank[2][0] == leading_rank:
                                contenders_4.append(player)
                        winners = contenders_4
                        return winners


            #check straights
            elif high_hand == 5:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                winners = contenders_2
                return winners


            #check flush
            if high_hand == 6:
                end_of_list = len(contenders) - 1
                remaining_suits = []
                leading_suit = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[3]['suit'])
                remaining_suits.sort()
                leading_suit = remaining_suits(end_of_list)
                suit_contenders = []
                for player in contenders:
                    if player.hand_rank[3]['suit'] == leading_suit:
                        suit_contenders.append(player)
                if suit_contenders == 1:
                    winners.append(suit_contenders[0])
                    return winners
                else:
                    #if the suit ties check highcard of flush
                    end_of_list = len(suit_contenders) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in suit_contenders:
                        remaining_ranks.append(player.hand_rank[1])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_2 = []
                    for player in suit_contenders:
                        if player.hand_rank[1] == leading_rank:
                            contenders_2.append(player)
                    if contenders_2 == 1:
                        winners.append(contenders_2[0])
                        return winners
                    else:
                        #if the flush ties evaluate highest kicker
                        end_of_list = len(contenders_2) - 1
                        remaining_ranks = []
                        leading_rank = None
                        for player in contenders_2:
                            remaining_ranks.append(player.hand_rank[2][3])
                        remaining_ranks.sort()
                        leading_rank = remaining_ranks[end_of_list]
                        contenders_3 = []
                        for player in contenders_2:
                            if player.hand_rank[2][3] == leading_rank:
                                contenders_3.append(player)
                        if contenders_3 == 1:
                            winners.append(contenders_3[0])
                            return winners
                        else:
                            #if the highest kicker ties evaluate second highest kicker
                            end_of_list = len(contenders_3) - 1
                            remaining_ranks = []
                            leading_rank = None
                            for player in contenders_3:
                                remaining_ranks.append(player.hand_rank[2][2])
                            remaining_ranks.sort()
                            leading_rank = remaining_ranks[end_of_list]
                            contenders_4 = []
                            for player in contenders_3:
                                if player.hand_rank[2][2] == leading_rank:
                                    contenders_4.append(player)
                            if contenders_4 == 1:
                                winners.append(contenders_4[0])
                                return winners
                            else:
                                #if the second highest kicker ties evaluate third highest kicker
                                end_of_list = len(contenders_4) - 1
                                remaining_ranks = []
                                leading_rank = None
                                for player in contenders_4:
                                    remaining_ranks.append(player.hand_rank[2][1])
                                remaining_ranks.sort()
                                leading_rank = remaining_ranks[end_of_list]
                                contenders_5 = []
                                for player in contenders_5:
                                    if player.hand_rank[2][1] == leading_rank:
                                        contenders_5.append(player)
                                if contenders_5 == 1:
                                    winners.append(contenders_5[0])
                                    return winners
                                else:
                                #if the third highest kicker ties evaluate lowest kicker
                                    end_of_list = len(contenders_5) - 1
                                    remaining_ranks = []
                                    leading_rank = None
                                    for player in contenders_5:
                                        remaining_ranks.append(player.hand_rank[2][0])
                                    remaining_ranks.sort()
                                    leading_rank = remaining_ranks[end_of_list]
                                    contenders_6 = []
                                    for player in contenders_6:
                                        if player.hand_rank[2][0] == leading_rank:
                                            contenders_6.append(player)
                                    winners = contenders_6
                                    return winners


            #check boat
            elif high_hand == 7:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                if contenders_2 == 1:
                    winners.append(contenders_2[0])
                    return winners
                else:
                #if the trips ties evaluate the pair
                    end_of_list = len(contenders_2) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in contenders_2:
                        remaining_ranks.append(player.hand_rank[2])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_3 = []
                    for player in contenders_2:
                        if player.hand_rank[2] == leading_rank:
                            contenders_3.append(player)
                    winners = contenders_3
                    return winners


            #check quads
            elif high_hand == 8:
                end_of_list = len(contenders) - 1
                remaining_ranks = []
                leading_rank = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[1])
                remaining_ranks.sort()
                leading_rank = remaining_ranks[end_of_list]
                contenders_2 = []
                for player in contenders:
                    if player.hand_rank[1] == leading_rank:
                        contenders_2.append(player)
                if contenders_2 == 1:
                    winners.append(contenders_2[0])
                    return winners
                else:
                #if the quads ties evaluate the kicker
                    end_of_list = len(contenders_2) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in contenders_2:
                        remaining_ranks.append(player.hand_rank[2])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_3 = []
                    for player in contenders_2:
                        if player.hand_rank[2] == leading_rank:
                            contenders_3.append(player)
                    winners = contenders_3
                    return winners



            #check straightflush
            if high_hand == 9:
                end_of_list = len(contenders) - 1
                remaining_suits = []
                leading_suit = None
                for player in contenders:
                    remaining_ranks.append(player.hand_rank[2]['suit'])
                remaining_suits.sort()
                leading_suit = remaining_suits(end_of_list)
                suit_contenders = []
                for player in contenders:
                    if player.hand_rank[2]['suit'] == leading_suit:
                        suit_contenders.append(hand)
                if suit_contenders == 1:
                    winners.append(suit_contenders[0])
                    return winners
                else:
                    #if the suit ties check highcard of straightflush
                    end_of_list = len(suit_contenders) - 1
                    remaining_ranks = []
                    leading_rank = None
                    for player in suit_contenders:
                        remaining_ranks.append(player.hand_rank[1])
                    remaining_ranks.sort()
                    leading_rank = remaining_ranks[end_of_list]
                    contenders_2 = []
                    for player in suit_contenders:
                        if player.hand_rank[1] == leading_rank:
                            contenders_2.append(player)
                    winners = contenders_2
                    return winners





















#!/usr/bin/env python

#minimum reraises and capping action with short all ins:
#http://poker.stackexchange.com/questions/158/minimum-re-raise-in-hold-em


# button rules in heads up:
#http://www.888poker.co.uk/how-to-play/heads-up-poker-rules

#dead blinds, including when going to heads up
#http://www.texasholdem-poker.com/dead-blinds



import sys
import deck
import pokertable
import players
import dealer_holdem
import rules_holdem
import betting_rounds_holdem
import tests

import time
import logging

from copy import deepcopy


cody = players.Player('cody4321', 1500)
darren = players.Player('d_money', 1500)
katelyn = players.Player('yuppitsme', 1500)
mike = players.Player('it\'s_massey\'s_world', 1500)
jon = players.Player('no_rules_2014', 1500)
derek = players.Player('dwreck', 1500)
table_players = [cody, darren, katelyn, mike, jon, derek]
newtable = pokertable.Table(table_players, 20, 10, 0)


#for player in table_players:
    #print (player.screen_name)


#active_players_list = newtable.players_list
#amount_of_players = len(players_list)
button = 0
button_bucket = 0
big_blind = 20
small_blind = 10




# to change button, constantly add 1 to button bucket, and % that beast by the amount of players at the table
# once the button rounds the table of 6 players, bucket has 6. next hand bucket has 7, 7%6 = 1, it returns to the start
# for us, seat 1 is actually seat 0


class Hand():

    #bets_to_match = []

    #pots = []

    suits_dict = {1: 'c', 2: 'd', 3: 'h', 4: 's'}
    ranks_dict = {1: '2', 2: '2', 3: '3', 4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9', 10: '10', 11: 'J', 12: 'Q', 13: 'K', 14: 'A'}


    @staticmethod
    def reset_round(players):
        for player in players:
            player.current_bet = 0
            player.checked = False
            #player.small_blind = False
            #player.big_blind = False


    @staticmethod
    def reset_hand(players):
        for player in players:
            player.current_bet = 0
            player.current_investment = 0
            player.starting_chips = player.chips
            player.checked = False
            player.has_hand = False
            player.all_in = False
            player.small_blind = False
            player.big_blind = False
            player.cards = []


    @staticmethod
    def start_hand(active_players, button, big_blind, small_blind, deck, one_big_blind):

        players = active_players
        number_of_players = len(players)
        #for player in players:
            #print 'in start_hand...player %s chips = %d' % (player.screen_name, player.chips)
        seat_order_of_players_list = []
        seats_list = []
        for player in players:
            seats_list.append(player.seat)
        seats_list.sort()
        for seat in seats_list:
            for player in players:
                if player.seat == seat:
                    seat_order_of_players_list.append(player)
                    break

        #screen_name_list = ''
        #for player in seat_order_of_players_list:
            #screen_name_list += player.screen_name
            #screen_name_list += ', '
        #print '\n'
        #print 'Seat order of players list: %s' % screen_name_list
        #print '\n'


        active_players_list = players

        dealer_holdem.Dealer().deal_player_hand(active_players_list, deck)

        for player in active_players_list:
            player.has_hand = True


        player_count = len(active_players_list)

        if player_count > 2:
            if one_big_blind == False:
                preflop_list = active_players_list[((button + 3) % player_count):] + active_players_list[0:((button + 3)% player_count)]
                postflop_list = active_players_list[((button + 1) % player_count):] + active_players_list[0:((button + 1) % player_count)]
            else:
                preflop_list = active_players_list[((button + 2) % player_count):] + active_players_list[0:((button + 2)% player_count)]
                postflop_list = active_players_list[((button + 1) % player_count):] + active_players_list[0:((button + 1) % player_count)]
        elif player_count == 2:
                preflop_list = active_players_list[button:]  #+ active_players_list[0:button]
                postflop_list = active_players_list[(button + 1)] + active_players_list[button]

        print '\nstarting hand, button = %d\n' % button

        screen_name_list = ''
        for player in active_players_list:
            screen_name_list += player.screen_name
            screen_name_list += ', '
        print '\n'
        print 'Active players list within "start_hand": %s' % screen_name_list
        print '\n'
        print 'The button within "start_hand": %d' % button
        print 'How many players? %d' % player_count

        small_blind_start = None

        if one_big_blind == False:
            if player_count > 2:
                small_blind_start = ((button + 1) % player_count)
                big_blind_start = ((button + 2) % player_count)
            elif player_count == 2:
                small_blind_start = button
                big_blind_start = (button + 1)
            elif player_count == 1:
                print 'Error, player count is 1 but game is still running!'
        elif one_big_blind == True:
            big_blind_start = (button + 1)

        #if small_blind_start:
            #print 'small blind start: %d' % small_blind_start
        #print 'big blind start: %d \n' % big_blind_start

        if one_big_blind == False:
            pots = Hand().handle_small_blind(small_blind, big_blind, active_players_list[((button + 1) % player_count)])
            print '\n'
            pots = Hand().handle_big_blind(small_blind, big_blind, active_players_list[((button + 2) % player_count)], pots)
        elif one_big_blind == True:
            pots = Hand().handle_single_big_blind(big_blind, active_players_list[((button + 1) % player_count)])

        print pots

        the_button = None
        for index, player in enumerate(active_players_list):
            if index == button:
                the_button = player
                break
        print '\n %s is the button' % the_button.screen_name

        return (preflop_list, pots, active_players_list, postflop_list)


    @staticmethod
    def handle_small_blind(small_blind, big_blind, player):

        print '%s is the small blind.' % player.screen_name
        print 'player\'s chips before handling small blind: %d' % player.chips

        player.small_blind = True

        if player.chips > small_blind:
            pots = [{'pot': small_blind, 'match': big_blind, 'any_all_in': False}]
            player.chips -= small_blind
            player.current_bet = small_blind
            player.current_investment += small_blind

        if player.chips == small_blind:
            pots = [{'pot': small_blind,'match': small_blind, 'any_all_in': True}]
            player.chips = 0
            player.current_bet = small_blind
            player.all_in = True
            player.current_investment += small_blind

        if player.chips < small_blind:
            pots = [{'pot': player.chips, 'match': player.chips, 'any_all_in': True}]
            player.current_bet = player.chips
            player.current_investment += player.chips
            player.chips = 0
            player.all_in = True

        print 'player\'s chips after handling small blind: %d' % player.chips
        return pots


    @staticmethod
    def handle_big_blind(small_blind, big_blind, player, pots):

    #NOT DONE!!!!
        player.big_blind = True

        print '%s is the big blind.' % player.screen_name
        print 'player\'s chips before handling big blind: %d' % player.chips
        if player.chips > big_blind:

            if pots[0]['any_all_in'] == True:
                pots[0]['pot'] = pots[0]['pot'] + pots[0]['match']
                side_pot_amount = (big_blind - pots[0]['match'])
                pots.insert(1, [{'pot': side_pot_amount,'match': big_blind, 'any_all_in': False}])
                player.chips -= big_blind
                player.current_bet = big_blind
                player.current_investment += big_blind

            elif pots[0]['any_all_in'] == False:
                pots[0]['pot'] += big_blind
                player.chips -= big_blind
                player.current_bet = big_blind
                player.current_investment += big_blind



        if player.chips == big_blind:
            if pots[0]['any_all_in'] == True:
                pots[0]['pot'] = pots[0]['pot'] + pots[0]['match']
                side_pot_amount = (big_blind - pots[0]['match'])
                pots.insert(1, [{'pot': side_pot_amount,'match': big_blind, 'any_all_in': True}])
                player.chips = 0
                player.current_bet = big_blind
                player.current_investment += big_blind
                player.all_in = True

            elif pots[0]['any_all_in'] == False:
                pots[0]['pot'] += big_blind
                pots[0]['any_all_in'] = True
                player.chips = 0
                player.current_bet = big_blind
                player.current_investment += big_blind
                player.all_in = True



        if player.chips < big_blind:
            if pots[0]['any_all_in'] == True:
                if player.chips < pots[0]['match']:
                    main_pot_amount = player.chips * 2
                    pots.insert(0, [{'pot': main_pot_amount,'match': player.chips, 'any_all_in': True}])
                    player.current_bet = player.chips
                    player.current_investment += player.chips
                    player.chips = 0
                    player.all_in = True
                elif player.chips == pots[0]['match']:
                    main_pot_amount = player.chips * 2
                    pots.insert(0, [{'pot': main_pot_amount,'match': player.chips, 'any_all_in': True}])
                    player.current_bet = player.chips
                    player.current_investment += player.chips
                    player.chips = 0
                    player.all_in = True
                elif player.chips > pots[0]['match']:
                    pots[0]['pot'] = pots[0]['match'] * 2
                    side_pot_amount = player.chips - pots[0]['match']
                    pots.insert(1, [{'pot': side_pot_amount,'match': player.chips, 'any_all_in': True}])
                    player.current_bet = player.chips
                    player.current_investment += player.chips
                    player.chips = 0
                    player.all_in = True

            elif pots[0]['any_all_in'] == False:
                if player.chips < small_blind:
                    main_pot_amount = (small_blind - player.chips) * 2
                    pots.insert(0, [{'pot': main_pot_amount,'match': player.chips, 'any_all_in': True}])
                    pots[1]['pot'] -= player.chips
                    player.current_bet = player.chips
                    player.current_investment += player.chips
                    player.chips = 0
                    player.all_in = True
                elif player.chips == small_blind:
                    main_pot_amount = small_blind * 2
                    pots[0]['pot'] = main_pot_amount
                    pots[0]['any_all_in'] = True
                    player.current_bet = player.chips
                    player.current_investment += player.chips
                    player.chips = 0
                    player.all_in = True
                elif player.chips > small_blind:
                    pots[0]['pot'] = small_blind * 2
                    pots[0]['any_all_in'] = True
                    side_pot_amount = player.chips - small_blind
                    pots.insert(1, [{'pot': side_pot_amount,'match': player.chips, 'any_all_in': True}])
                    player.current_bet = player.chips
                    player.current_investment += player.chips
                    player.chips = 0
                    player.all_in = True

        print 'player\'s chips after handling big blind: %d' % player.chips
        return pots


    @staticmethod
    def handle_single_big_blind(big_blind, player):

        print '%s is the big blind.' % player.screen_name
        print 'player\'s chips before handling big blind: %d' % player.chips

        player.big_blind = True

        if player.chips > big_blind:
            pots = [{'pot': big_blind, 'match': big_blind, 'any_all_in': False}]
            player.chips -= big_blind
            player.current_bet = big_blind
            player.current_investment += big_blind

        if player.chips == big_blind:
            pots = [{'pot': big_blind,'match': big_blind, 'any_all_in': True}]
            player.chips = 0
            player.current_bet = big_blind
            player.all_in = True
            player.current_investment += big_blind

        if player.chips < big_blind:
            pots = [{'pot': player.chips, 'match': player.chips, 'any_all_in': True}]
            player.current_bet = player.chips
            player.current_investment += player.chips
            player.chips = 0
            player.all_in = True

        print 'player\'s chips after handling big blind: %d' % player.chips
        return pots


    # dont worry about legal bets here; the betting round function screens out illegal bets
    # bet is player.current_bet
    # current_bet is the current bet at the table
    # list.insert(i, x) where i is the index to insert BEFORE



    @staticmethod
    def award_pot(remaining_players, pots):


        print 'Remaining players: %s' % remaining_players

        if len(remaining_players) == 1:
            winner = remaining_players[0]
            for pot in pots:
                winner.chips += pot['pot']
            return 1

        for pot in pots:
            eligible_players = []
            for player in remaining_players:
                if player.starting_chips >= pot['match']:
                    eligible_players.append(player)

            winners = rules_holdem.Holdem_rules().compare_hands(eligible_players)
            print 'winners: %s' % winners
            number_of_winners = len(winners)
            print 'number of winners: %d' % number_of_winners
            remainder = pot['pot'] % number_of_winners
            division_of_pot = (pot['pot'] - remainder) / number_of_winners
            for player in winners:
                player.chips += division_of_pot
            for number in range(remainder):
                winners[number].chips += 1
        return 1


    @staticmethod
    def run_hand(players, button, big_blind, small_blind, one_big_blind):
        #ignore bigblind for now. may want to split off a small method called init_hand to make the players lists for preflop, postflop, init the small
        # blind and bigblind bets

        newdeck = deck.Deck()

        Hand().reset_hand(players)

        start_hand = Hand().start_hand(players, button, big_blind, small_blind, newdeck, one_big_blind)

        preflop_list = start_hand[0]

        postflop_list = start_hand[3]

        pots = start_hand[1]

        active_players_list = start_hand[2]

        everybody_all_in = False

        was_one_big_blind = False

        if one_big_blind:
            was_one_big_blind = True


        print ('\nf to fold, c to call, and a number to raise. let\'s gamble, son!!!\n')

        for player in active_players_list:
            print ('%s: %s %s%s, %s%s' % (player.screen_name, player.chips, Hand().ranks_dict[player.cards[0].Rank], Hand().suits_dict[player.cards[0].Suit], Hand().ranks_dict[player.cards[1].Rank], Hand().suits_dict[player.cards[1].Suit]))

        print '\npreflop'

        #for player in active_players_list:
            #print '%s chips: %d' % (player.screen_name, player.chips)

        #PREFLOP
        screen_name_list = ''
        for player in preflop_list:
            screen_name_list += player.screen_name
            screen_name_list += ', '
        print '\n'
        print 'Preflop list within "run_hand" before dealing preflop: %s' % screen_name_list
        screen_name_list = ''
        for player in postflop_list:
            screen_name_list += player.screen_name
            screen_name_list += ', '
        print 'Postflop list within "run_hand" before dealing preflop: %s' % screen_name_list
        print '\n'

        #preflop = Hand().betting_round(preflop_list, big_blind, 0, pots, True, big_blind)
        preflop = betting_rounds_holdem.Betting_Rounds().betting_round_preflop(preflop_list, big_blind, 0, pots, big_blind)
        pots = preflop[1]
        #print preflop
        if preflop[0]['hand_over'] == True:
            print '\nhand_over == True\n'
            Hand().award_pot(preflop[2], pots)
            return (active_players_list, was_one_big_blind)
        else:
            print '\nflop\n'
            #FLOP
            print 'Dealing flop\n'
            flop_board = dealer_holdem.Dealer().deal_flop(newdeck)
            Hand().reset_round(active_players_list)

            if preflop[3]['everybody_all_in'] == True:
                everybody_all_in = True
            if everybody_all_in == True:
                flop = preflop
            else:
                flop = betting_rounds_holdem.Betting_Rounds().betting_round_postflop(postflop_list, 0, big_blind, pots, big_blind, flop_board)
            #print flop
            #print flop[1]
            pots = flop[1]
            print flop
            if flop[0]['hand_over'] == True:
                print 'hand_over == True'
                Hand().award_pot(flop[2], pots)
                return (active_players_list, was_one_big_blind)
            else:
                print '\nturn\n'
                #TURN
                print '\nDealing turn\n'
                turn_board = dealer_holdem.Dealer().deal_turn(newdeck, flop_board)

                if flop[3]['everybody_all_in'] == True:
                    everybody_all_in = True
                if everybody_all_in == True:
                    turn = flop

                else:
                    Hand().reset_round(active_players_list)
                    turn = betting_rounds_holdem.Betting_Rounds().betting_round_postflop(postflop_list, 0, big_blind, pots, big_blind, turn_board)
                pots = turn[1]
                if turn[0]['hand_over'] == True:
                    print 'hand_over == True'
                    Hand().award_pot(turn[2], pots)
                    return (active_players_list, was_one_big_blind)
                else:
                    print '\nriver\n'
                    #RIVER
                    print 'Dealing river\n\n'
                    final_board = dealer_holdem.Dealer().deal_river(newdeck, turn_board)
                    if turn[3]['everybody_all_in'] == True:
                        everybody_all_in = True
                    if everybody_all_in == True:
                        river = turn
                    else:
                        Hand().reset_round(active_players_list)
                        river = betting_rounds_holdem.Betting_Rounds().betting_round_postflop(postflop_list, 0, big_blind, pots, big_blind, final_board)
                    #print river[0]['hand_over']
                    #print river[1]
                    pots = river[1]
                    if river[0]['hand_over'] == True:
                        print 'hand_over == True'
                        Hand().award_pot(river[2], pots)
                        return (active_players_list, was_one_big_blind)
                    else:
                        remaining_players = []
                        for player in active_players_list:
                            if player.has_hand == True:
                                remaining_players.append(player)
                        for player in remaining_players:
                            for card in final_board:
                                player.cards.append(card)
                        print "right before awarding pot"
                        Hand().award_pot(remaining_players, pots)
                        return (active_players_list, was_one_big_blind)
                        #hands must be evaluated...need to finish writing "compare hands"

    @staticmethod
    def make_hand_dicts():
        pass


    @staticmethod
    def run_poker_game(players, big_blind, small_blind):

        total_chipcount = tests.Test().determine_total_chipcount(players)

        length = 2*len(players)

        raw_button = length

        first_hand = True

        for index, player in enumerate(players):
            player.seat = (index + 1)

        while True:
            players_with_chips = 0
            for player in players:
                if player.chips > 0:
                    players_with_chips += 1
            winner = []
            if players_with_chips == 1:
                for player in players:
                    if player.chips > 0:
                        print '\nThe winner is: %s!!!' % player.screen_name
                        print 'how many chip he got? %d' % player.chips
                        winner.append(player)
                time.sleep(3)
                print '\nThe winner is: %s!!!' % winner
                return (winner)


            if first_hand == True:
                HAND = list_of_players_from_last_hand = Hand().run_hand(players, 0, big_blind, small_blind, False)
            else:
                Hand().reset_round(players)
                HAND = Hand().run_hand(active_players_list, new_button, big_blind, small_blind, one_big_blind)
            first_hand = False

            tests.Test().ensure_chipcount(players, total_chipcount)

            list_of_players_from_last_hand = HAND[0]
            was_one_big_blind_previously = HAND[1]
            one_big_blind = False
            big_blind_busted = False
            length = len(list_of_players_from_last_hand)

            other_list = deepcopy(list_of_players_from_last_hand)

            previous_button = None
            for index, player in enumerate(list_of_players_from_last_hand):
                if player.big_blind == True:
                    previous_button = index
            new_blind_check_list = list_of_players_from_last_hand[(previous_button + 1):] + list_of_players_from_last_hand[0:(previous_button + 1)]

            new_big_blind_player = None
            while True:
                for player in new_blind_check_list:
                    if player.chips > 0:
                        new_big_blind_player = player
                        break
                break


            for index, player in enumerate(list_of_players_from_last_hand):
                if player.big_blind == True and player.chips == 0:
                    one_big_blind = True
                    break


            new_big_blind_player_screen_name = new_big_blind_player.screen_name
            new_button = 0
            active_players_list_screen_names = []
            for player in players:
                if player.chips > 0:
                    active_players_list_screen_names.append(player.screen_name)
            active_players_list = []
            for player in players:
                if player.chips > 0:
                    active_players_list.append(player)

            active_players_list_length = len(active_players_list)

            button_displacement = None

            if one_big_blind == True:
                button_displacement = 1
            else:
                button_displacement = 2

            index_for_new_big_blind = None

            for index, player in enumerate(active_players_list_screen_names):
                if player == new_big_blind_player_screen_name:
                    index_for_new_big_blind = index

            #print 'index for new big blind: %d' % index_for_new_big_blind
            #print 'button_displacement: %d' % button_displacement

            if index_for_new_big_blind == 0:
                if button_displacement == 1:
                    new_button = (active_players_list_length - 1)
                if button_displacement == 2:
                    new_button = (active_players_list_length - 2)
            if index_for_new_big_blind == 1:
                if button_displacement == 1:
                    new_button = (index_for_new_big_blind - 1)
                if button_displacement == 2:
                    new_button = (active_players_list_length - 1)
            if index_for_new_big_blind > 1:
                if button_displacement == 1:
                    new_button = (index_for_new_big_blind - 1)
                if button_displacement == 2:
                    new_button = (index_for_new_big_blind - 2)



            new_button_player = active_players_list[new_button]
            new_button_player_screen_name = new_button_player.screen_name

            print active_players_list_screen_names
            print active_players_list
            print '\n'
            print 'new button = %d\n' % new_button
            print 'new button player.screen name: %s' % active_players_list_screen_names[new_button]

        return 1



def run_poker_game(): 
    Hand().run_poker_game(table_players, 20, 10)




        #to run the test file
# python ~/Desktop/poker_site/game.py



from setuptools import setup

setup(
    name='poker-program-demo',
    version='0.1.0',
    description='play poker; my first python project to learn',
    url='https://bitbucket.org/codyc54321/poker_program_demo',
    author='Cody Childers',
    author_email='cchilder@mail.usf.edu',
    license='MIT',
    packages=['holdem'],
    install_requires=[],
    zip_safe=False,
    entry_points={
        'console_scripts': ['play-poker=holdem.holdem_game:run_poker_game']
    }
)




import time

import organize_pots

class Ranks():
    suits_dict = {1: 'c', 2: 'd', 3: 'h', 4: 's'}
    ranks_dict = {1: '2', 2: '2', 3: '3', 4: '4', 5: '5', 6: '6', 7: '7', 8: '8', 9: '9', 10: '10', 11: 'J', 12: 'Q', 13: 'K', 14: 'A'}



class Betting_Rounds():
#forced bet is like big blind, what everyone pays. after the flop, forced bet is 0, but there's still a minimum bet (usually the big blind, or 2x BB)
    @staticmethod
    def betting_round_preflop(players, forced_bet, minimum_bet, current_pots, big_blind):

        pots = current_pots

        big_blind_checked = False

        amount_of_players_remaining = len(players)

        pots = current_pots
        players_list = players
        print '\nstarting betting round!!!'
        current_bet = forced_bet
        raise_amount = 0
        required_raise = 0
        if minimum_bet > 0 and forced_bet == 0:
            required_raise = minimum_bet
        else:
            required_raise = 2 * forced_bet
         
        old_bet = 0

        while True:
            for index, player in enumerate(players):
                if player.chips == 0:
                    player.all_in = True

                owe = current_bet - player.current_bet
                if owe == 0 and player.checked == True:
                    continue

                if player.has_hand == False:
                    continue
                
                #user interaction: for each player's turn, give info
                print ('\nOn %s, %d chips' % (player.screen_name, player.chips))
                print ('Your cards are: %s%s, %s%s' % (Ranks().ranks_dict[player.cards[0].Rank], Ranks().suits_dict[player.cards[0].Suit], Ranks().ranks_dict[player.cards[1].Rank], Ranks().suits_dict[player.cards[1].Suit]))
                print 'Is all in? : %s' % player.all_in
                print 'Current bet: %s' % player.current_bet
                print 'Current investment: %s' % player.current_investment
                print 'Has hand? : %s' % player.has_hand
                print 'Checked? : %s' % player.checked
                print 'The current bet is %d' % current_bet
                print ('The current raise is: %d' % raise_amount)
                print ('The required raise is: %d' % required_raise)
                print 'Your current bet is %d' % player.current_bet
                print 'You owe: %d' % owe
                print 'You can bet up to: %d' % (player.current_bet + player.chips)
                print '\n'
                #give info about pots/sidepots during each player's turn
                pot_counter = 0
                for pot in pots:
                    print 'Pot %d:' % (pot_counter + 1)
                    print 'Pot size: %d' % pots[pot_counter]['pot']
                    print 'Bet to match for this pot: %d' % pots[pot_counter]['match']
                    print 'Any all in? %s' % pots[pot_counter]['any_all_in']
                    pot_counter += 1
 
                calling_all_in = False
                while True:
                    if current_bet > 0:
                        #if player cannot match the bet and has to choose all in vs. fold
                        if player.chips + player.current_bet <= current_bet:
                            action = raw_input("Do you want to call all in? y or n: ")
                            if action == 'y' or action == 'yes':
                                calling_all_in = True
                                break
                            elif action == 'n' or action == 'no':
                                player.has_hand = False
                                player.cards = []
                                player.current_bet = 0
                                break
                            else:
                                continue
                    break
                #check if BB already had their option in case a player raises and the BB later calls the raise, or it will cause an infinite loop
                went_through_big_blind_option_code = False
                if player.has_hand == True:
                    while True:
                        if calling_all_in == True:
                            player_bet = player.chips + player.current_bet
                            print 'ALL IN!'
                            pots = organize_pots.Organize_Pots().organize_pots(player_bet, player, pots, players_list)
                            break
                        if current_bet == big_blind and player.big_blind == True:
                            print 'big blind player current bet: %d' % player.current_bet
                            player_bet = raw_input("\nYou can bet an integer,\ncheck your big blind with 'c' or 'check',\nor fold if you just don\'t want to play: ")
                            went_through_big_blind_option_code = True
                            print 'player bet: %s' % player_bet
                            if player_bet == 'c' or player_bet == 'check':
                                player.checked = True
                                big_blind_checked = True
                                print ('\nYou decided to check your option\n')
                                break
                            test_bet = int(player_bet)
                            if test_bet == big_blind:
                                print 'your bet is equal to blinds, you check'
                                player.checked = True
                                big_blind_checked = True
                                break

                        if went_through_big_blind_option_code == False:
                            player_bet = raw_input("\nYou can bet an integer,\nsay 'f' or 'fold' to fold,\nor say 'c' or 'check' to check, if the current bet is 0: ")
                        if player_bet == 'f' or player_bet == 'fold':
                            player.has_hand = False
                            player.cards = []
                            player.current_bet = 0
                            print '\nYou decided to fold\n'
                            break
                        if current_bet == 0 and player_bet == 'c' or current_bet == 0 and player_bet == 'check':
                            print ('\nYou decided to check\n')
                            player.checked = True
                            break
                        try:
                            bet = int(player_bet)
                        except ValueError:
                            print ('Enter an integer.')
                            continue
                        #if bet > current_bet and not bet >= (current_bet + (2 * current_raise)):
                        if (player.chips + player.current_bet - bet) == 0:
                            print ('ALLLLLLLL INNNNNNNN!!!!!!!!!!')
                            if bet >= required_raise:
                                old_bet = current_bet
                                raise_amount = bet - old_bet
                                pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                                current_raise = (2 * (bet - current_bet) + current_bet)
                                required_raise = ((2 * raise_amount) + old_bet)
                                print 'required raise: %d' % required_raise
                                current_bet = bet
                                print('%s chips: %d' % (player.screen_name, player.chips))
                                break
                            elif bet < required_raise:
                                old_bet = current_bet
                                pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                                current_bet = bet
                                print('%s chips: %d' % (player.screen_name, player.chips))
                                break
                        elif bet > current_bet and not bet >= required_raise:
                            print ('If you\'d like to raise, enter a number at least twice the current bet.')
                            continue
                        elif current_bet > bet:
                            print ('That is smaller than the current bet. Stop cheating, you cheapskate!!!')
                            continue
                        elif bet > player.chips:
                            print ('You don\'t have enough chips to bet that much! Make a valid bet.')
                            continue
                        elif current_bet == 0 and bet == 0:
                            print ('\nYou decided to check\n')
                            player.checked = True
                            break
                        elif bet == current_bet:
                            pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                            print ('%s chips: %d' % (player.screen_name, player.chips))
                            break
                        else:
                            old_bet = current_bet
                            raise_amount = bet - old_bet
                            #current_raise = (2 * (bet - current_bet) + current_bet)
                            required_raise = ((2 * raise_amount) + old_bet)
                            pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                            print 'required raise: %d' % required_raise
                            current_bet = bet
                            print('%s chips: %d' % (player.screen_name, player.chips))
                            break
                print 'current bet: %d' % current_bet
                print "\nmade it to left_to_act code\n"
                #end the game with a winner
                left_to_act = 0
                players_with_hands = 0
                all_in_players = []
                remaining_players = []
                    
                for player in players:
                    if player.has_hand == True:
                        players_with_hands += 1
                        remaining_players.append(player)
                        if player.all_in == True:
                            all_in_players.append(player)
                            continue
                        if player.current_bet < current_bet:
                            left_to_act += 1
                        if current_bet == big_blind and player.current_bet == current_bet and player.big_blind == True and player.checked == False:
                            left_to_act += 1
                        if current_bet == 0:
                            if player.current_bet == 0:
                                if not player.checked:
                                    left_to_act += 1

                
                if players_with_hands == 1:
                    winner = []
                    for player in players:
                        if player.has_hand == True:
                            winner.append(player)
                    return ({'hand_over': True}, pots, winner)
                if players_with_hands == len(all_in_players):
                    return ({'hand_over': False}, pots, all_in_players, {'everybody_all_in': True})
                if left_to_act == 0:
                    print "\nround is over\n"
                    pot_counter = 0
                    print '\nEnding of "betting_round"...'
                    return ({'hand_over': False}, pots, remaining_players, {'everybody_all_in': False})






    #forced bet is like big blind, what everyone pays. after the flop, forced bet is 0, but there's still a minimum bet (usually the big blind, or 2x BB)
    @staticmethod
    def betting_round_postflop(players, forced_bet, minimum_bet, current_pots, big_blind, board):

        pots = current_pots

        amount_of_players_remaining = len(players)

        pots = current_pots
        players_list = players
        print '\nstarting betting round!!!'
        current_bet = forced_bet
        raise_amount = 0
        required_raise = 0
        if minimum_bet > 0 and forced_bet == 0:
            required_raise = minimum_bet
        else:
            required_raise = 2 * forced_bet
         
        old_bet = 0
                
        while True:       
            for index, player in enumerate(players):

                if player.chips == 0:
                    player.all_in = True

                owe = current_bet - player.current_bet
                if owe == 0 and player.checked == True:
                    continue

                if player.has_hand == False:
                    continue

                if player.all_in == True:
                    continue


                card_sub = ''
                count = 0
                for card in board:
                    card_sub += Ranks().ranks_dict[board[count].Rank]
                    card_sub += Ranks().suits_dict[board[count].Suit]
                    card_sub +=' '
                    count += 1
                print '\nBoard: %s' % card_sub


                print ('\nOn %s, %d chips' % (player.screen_name, player.chips))
                print ('Your cards are: %s%s, %s%s' % (Ranks().ranks_dict[player.cards[0].Rank], Ranks().suits_dict[player.cards[0].Suit], Ranks().ranks_dict[player.cards[1].Rank], Ranks().suits_dict[player.cards[1].Suit]))
                print 'Current bet: %s' % player.current_bet
                print 'Current investment: %s' % player.current_investment
                print 'The current bet is %d' % current_bet
                print ('The current raise is: %d' % raise_amount)
                print ('The required raise is: %d' % required_raise)
                print 'Your current bet is %d' % player.current_bet
                print 'You owe: %d' % owe
                print 'You can bet up to: %d' % (player.current_bet + player.chips)
                print '\n'
                pot_counter = 0
                for pot in pots:
                    print 'Pot %d:' % (pot_counter + 1)
                    print 'Pot size: %d' % pots[pot_counter]['pot']
                    print 'Bet to match for this pot: %d' % pots[pot_counter]['match']
                    print 'Any all in? %s' % pots[pot_counter]['any_all_in']
                    pot_counter += 1
 
                calling_all_in = False
                while True:
                    if current_bet > 0:
                        if player.chips + player.current_bet <= current_bet:
                            action = raw_input("Do you want to call all in? y or n: ")
                            if action == 'y' or action == 'yes':
                                calling_all_in = True
                                break
                            elif action == 'n' or action == 'no':
                                player.has_hand = False
                                player.cards = []
                                player.current_bet = 0
                                break
                            else:
                                continue
                    break
                
                went_through_big_blind_option_code = False
                if player.has_hand == True:
                    while True:
                        if calling_all_in == True:
                            player_bet = player.chips + player.current_bet
                            print 'ALLL INNN!!!!!!!!!!!!!'
                            pots = organize_pots.Organize_Pots().organize_pots(player_bet, player, pots, players_list)
                            break
                        player_bet = raw_input("\nYou can bet an integer,\nsay 'f' or 'fold' to fold,\nor say 'c' or 'check' to check, if the current bet is 0: ")
                        if player_bet == 'f' or player_bet == 'fold':
                            player.has_hand = False
                            player.cards = []
                            player.current_bet = 0
                            print 'You decided to fold'
                            break
                        if current_bet == 0 and player_bet == 'c' or current_bet == 0 and player_bet == 'check':
                            print ('\nYou decided to check\n')
                            player.checked = True
                            break
                        try:
                            bet = int(player_bet)
                        except ValueError:
                            print ('Enter an integer.')
                            continue
                        #if bet > current_bet and not bet >= (current_bet + (2 * current_raise)):
                        if (player.chips + player.current_bet - bet) == 0:
                            print ('ALLLLLLLL INNNNNNNN!!!!!!!!!!')
                            if bet >= required_raise:
                                old_bet = current_bet
                                raise_amount = bet - old_bet
                                pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                                current_raise = (2 * (bet - current_bet) + current_bet)
                                required_raise = ((2 * raise_amount) + old_bet)
                                print 'required raise: %d' % required_raise
                                current_bet = bet
                                print('%s chips: %d' % (player.screen_name, player.chips))
                                break
                            elif bet < required_raise:
                                old_bet = current_bet
                                pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                                current_bet = bet
                                print('%s chips: %d' % (player.screen_name, player.chips))
                                break
                        elif bet > current_bet and not bet >= required_raise:
                            print ('If you\'d like to raise, enter a number at least twice the current bet, or twice the current raise plus the previous bet.')
                            continue
                        elif current_bet > bet:
                            print ('That is smaller than the current bet. Stop cheating, you cheapskate!!!')
                            continue
                        elif bet > player.chips:
                            print ('You don\'t have enough chips to bet that much!')
                            continue
                        elif current_bet == 0 and bet == 0:
                            print ('\nYou decided to check\n')
                            player.checked = True
                            break
                        elif bet == current_bet:
                            pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                            print ('%s chips: %d' % (player.screen_name, player.chips))
                            break
                        else:
                            old_bet = current_bet
                            raise_amount = bet - old_bet
                            #current_raise = (2 * (bet - current_bet) + current_bet)
                            #current_raise is now obsolete in newer version as of december 2014. leave in for record
                            required_raise = ((2 * raise_amount) + old_bet)
                            pots = organize_pots.Organize_Pots().organize_pots(bet, player, pots, players_list)
                            print 'required raise: %d' % required_raise
                            current_bet = bet
                            print('%s chips: %d' % (player.screen_name, player.chips))
                            break

                
                print "\nmade it to left_to_act code postflop\n"
                #end the game with a winner
                left_to_act = 0
                players_with_hands = 0
                all_in_players = []
                remaining_players = []
                for player in players:
                    if player.has_hand == True:
                        players_with_hands += 1
                        remaining_players.append(player)
                        if player.all_in == True:
                            all_in_players.append(player)
                            continue
                        if player.current_bet < current_bet:
                            left_to_act += 1
                            continue
                        if current_bet == 0:
                            if player.current_bet == 0:
                                if not player.checked:
                                    left_to_act += 1
                #if only one player has cards, they won the hand
                if players_with_hands == 1:
                    winner = []
                    for player in players:
                        if player.has_hand == True:
                            winner.append(player)
                    return ({'hand_over': True}, pots, winner)
                #all players are all in or all players except 1 are all in, but the board has to be dealt and a winner determined then pots distributed- hence hand not over but everybody all in == True
                if len(all_in_players) >= (players_with_hands - 1) and left_to_act == 0:
                    return ({'hand_over': False}, pots, remaining_players, {'everybody_all_in': True})
                #players still have hands, not everyone is all in, and next round should be bet on
                if left_to_act == 0:
                    print "\nround is over\n"
                    pot_counter = 0
                    print '\nEnding of "betting_round"...'
                    return ({'hand_over': False}, pots, remaining_players, {'everybody_all_in': False})
















class Player():
    def __init__(self, screen_name, chips):
        self.screen_name = screen_name
        self.starting_chips = int(chips)
        self.chips = int(chips)
        self.cards = []
        self.current_investment = 0
        self.current_bet = 0
        self.has_hand = False
        self.all_in = False
        self.checked = False
        self.small_blind = False
        self.big_blind = False
        self.hand_rank = None
        self.seat = None
        self.omaha_high_hand = None

    def deduct(self, chips):
        self.chips -= chips
        
    def award(self, chips):
        self.chips += chips
    

